==> knapster-0.9.tar.gz: knapster-0.9/knapster/extlineedit.h <==
/***************************************************************************
                          extlineedit.h  -  description
                             -------------------
    begin                : Mon Feb 28 2000
    copyright            : (C) 2000 by jade
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef EXTLINEEDIT_H
#define EXTLINEEDIT_H

#include <qwidget.h>
#include <qlineedit.h>

/**line edit with up/down arror mem
  *@author jade
  */

class ExtLineEdit: public QLineEdit  {
   Q_OBJECT

  QString prev[10]; // remember last 10
  int pos;
  int num;
  int top;
private slots:
  void retPressed();
protected:
  virtual void keyPressEvent ( QKeyEvent * e );
public: 
	ExtLineEdit(QWidget *parent=0, const char *name=0);
	virtual ~ExtLineEdit();
private:
  QString getPrev();
  QString getNext();
};

#endif

==> knapster-0.12.tar.gz: knapster-0.12/knapster/extlineedit.h <==
/***************************************************************************
                          extlineedit.h  -  description
                             -------------------
    begin                : Mon Feb 28 2000
    copyright            : (C) 2000 by jade
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef EXTLINEEDIT_H
#define EXTLINEEDIT_H

#include <qwidget.h>
#include <qlineedit.h>

/**line edit with up/down arrow mem
  *@author jade
  */

class ExtLineEdit: public QLineEdit  {
  Q_OBJECT

  QString prev[10]; // remember last 10
  int pos;
  int num;
  int top;
private slots:
  void retPressed();
protected:
  virtual void keyPressEvent ( QKeyEvent * e );
public: 
	ExtLineEdit(QWidget *parent=0, const char *name=0);
	virtual ~ExtLineEdit();
private:
  QString getPrev();
  QString getNext();
};

#endif
